<?php

/**
 * Carga de la configuración del sistema
 * @package MoonDragon
 * @version 3.0
 * @author Andrés Javier López <ajavier.lopez@gmail.com>
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License
 * @copyright TuApp.net 2011
 */

// Carga las rutas del sistema

require_once $moondragon_path.'/conf/paths.inc';

/* 
 * Carga de la librería Core
 * La librería core es la base de todo el sistema por lo que su carga es de manera especial
 */

require_once LIB.'/core/lib.core.inc';

Libs::import( 'Core' );

// Registro del manejo de errores

include CONF.'/errorReporting.inc';
ErrorHandler::init( $e_report, $e_debug, $e_system_info, $e_deprecated, $e_halt_callback );

// Valores de configuración del sistema

include CONF.'/registry.inc';

// Configuración de la base de datos

if(file_exists(CONF.'/connection.xml'))
{
    if( Database::connectFromXML( CONF.'/connection.xml' ) )
    {
	    Registry::set( 'online', true );
    }
    else
    {
	    Registry::set( 'online', false );
    }
}
else
{
    Registry::set('online', false);
    Registry::set('OFFLINE_ERROR', false);
}

// Inicio de sesión

Session::init();

// Crear árbol de secciones

// Seciones por defecto del sistema
include GLOBAL_CONF.'/sections.inc';

// Secciones dinámicas del sistema
if(file_exists(CONF.'/sections.xml'))
{
    SectionTree::loadFromXML( CONF.'/sections.xml' );
}
else
{
    Registry::set( 'DEFAULT_SECTION', 'md_home' );
}

Vars::set('title', Registry::get('title'));
Vars::set('base_url', Registry::get('base_url'));

// Cargar librerías externas al sistema

include CONF.'/libraries.inc';

// Funcion autoload para cargar clases adicionales de las librerías

function __autoload($class_name)
{
	$include = false;
		
	$file = CLASSES.'/class.'.strtolower($class_name).'.php';
	if(file_exists($file))
	{
		include_once $file;
		$include = true;
	}
	
	$libs = Libs::getLibraries();
	
	foreach($libs as $lib)
	{
		$file = LIB.'/'.$lib.'/classes/class.'.strtolower($class_name).'php';
		if(file_exists($file))
		{
			if($include === true)
			{
				trigger_error('La clase '.$class_name.' de la librería '.$lib.' esta en conflicto con otra clase existente', E_USER_ERROR);
			}
			$include = true;
			include_once $file;
		} 
	}
}

// Se cargan las funciones estándar definidas por el desarrollador

$functions = opendir(FUNC);

while(false !== ($func = readdir($functions)))
{
	if(!is_dir($func))
	{		
		include_once FUNC.'/'.$func;
	}
}

// Fin de archivo
