<?php

/**
 * Definición de la clase HTMLView
 * @package Core
 * @version 3.0
 * @license http://opensource.org/licenses/lgpl-3.0.html GNU Lesser General Public License
 * @copyright TuApp.net 2011
 */

/**
 * Vista base para salida en HTML
 * 
 * @author Andrés Javier López <ajavier.lopez@gmail.com>
 * @copyright TuApp.net 2011
 * @package Core
 * @abstract
 * @version 3.0
 */
 
abstract class HTMLView extends View
{
	/**
	 * Página principal de la aplicación
	 * @var string
	 */
	protected $page;
	
	/**
	 * Plantillas utilizadas por la vista
	 * @var array
	 */
	protected $templates;
	
	/**
	 * Contenido principal de la página
	 * @var string
	 */
	protected $content;
	
	
	/**
	 * Constructor de la clase
	 * @return void
	 */
	public function __construct()
	{
		parent::__construct();
		$this->page = Registry::get( 'DEFAULT_PAGE' );
		$this->templates = array();
	}
	
	/**
	 * Agrega contenido a la vista
	 * @param string $content
	 * @return void
	 */
	public function addContent( $content )
	{
		$this->content .= $content;
	}
	
	/**
	 * Modifica la página principal de la vista
	 * @param string $page
	 * @return void
	 */
	public function setPage( $page )
	{
		$this->page = $page;
	}

	/**
	 * Override del método show para mostrar el contenido
	 * @return void
	 * @see View::show()
	 */
	public function show()
	{
		$buffer = Buffer::getInstance();
		
		$message = $buffer->getContent( 'message' );
		
		if( $message != '' )
		{
			$this->addVar( 'message', $message );
		}
		
		$page = new Page( $this->page );
		$page->setVars( $this->getVars() );
		
		foreach( $this->templates as $name => $template )
		{
			$tpl = Template::load( $template, $this->vars );
			
			$page->addTemplate( $name, $tpl );
		}
		
		$content =  $buffer->getContent( 'salida' );
		
		if( ErrorHandler::$has_errors )
		{			
			$error =  '<pre>';
			$error .= $buffer->getContent( 'e_warning',false );
			$error .= $buffer->getContent( 'e_notice', false );
			$error .= '</pre>';
		}
		else
		{
			$error = '';
		}
		
		$page->setContent( $error.$content.$this->content );
		
		return $page->show();
	}
	
	/**
	 * Override del método message para publicar un mensaje
	 * @param string $string
	 * @return void
	 * @see View::message()
	 */
	public function message( $string )
	{
		$this->setPage( Registry::get( 'MESSAGE_PAGE' ));
		$buffer = Buffer::getInstance();
		$buffer->write( 'message', $string, true );
	}
		
	/**
	 * Agrega una plantilla a la vista
	 * @param string $name
	 * @param string $template
	 * @return void
	 */
	public function addTemplate( $name, $template )
	{
		$this->templates[$name] = $template;
	}
}

// Fin de archivo
