<?php

/**
 * Definición de la clase MoonDragon
 * @package Core
 * @version 3.0
 * @license http://opensource.org/licenses/lgpl-3.0.html GNU Lesser General Public License
 * @copyright TuApp.net 2011
 */

/**
 * Controlador central del sistema
 * 
 * @author Andrés Javier López <ajavier.lopez@gmail.com>
 * @copyright TuApp.net 2011
 * @package Core
 * @version 3.0
 */
 
class MoonDragon
{
	
	/**
	 * Proceso principal del sistema que se encarga de iniciar las tareas
	 * @return void
	 * @static
	 */
   	public static function start()
   	{
   		// Identificar la sección actual

        if( isset( $_REQUEST['sec'] ) )
        {
        	$_section = $_REQUEST['sec'];
        }
        else
        {
        	$_section = Registry::get( 'DEFAULT_SECTION' );
        }
        SectionTree::initSection( $_section );
        
        Vars::set( 'section', Registry::get('section') );
        Vars::set( 'section_name', Registry::get('section_name') );
        
        // Se obtiene el controlador asignado a la seccion
        
        $controller = self::getControllerFrom( Registry::get( 'section' ) );
        
        // Se obtiene la tarea solicitadas
        
        if( isset( $_REQUEST['task'] ) )
        {
        	$_task = $_REQUEST['task'];
        }
        else
        {
        	$_task = '';
        }
        
        // Se ejecuta la tarea
        
        $controller->run( $_task );
        
        // Envío de cabeceras
        
        if( headers_sent() )
        {
        	trigger_error( 'Las cabeceras se enviaron antes de tiempo', E_USER_WARNING );
        }
        else
        {
        	$location = Registry::get( 'redirect_location' );
        	if( $location != '' )
        	{
        		$errors = ErrorHandler::getWarnings();
        		$errors .= ErrorHandler::getNotices();
        		file_put_contents( LOGS.'/errorRedirect.log', $errors );
        		header( "Location: $location" );
        	}
        }
        
        // Se imprime a pantalla el contenido

        $view = Registry::get( 'view' );
        
        if( !($view instanceof View) )
        {
        	$view_name = Registry::get('DEFAULT_VIEW').'View';
        	$view = new $view_name();
        }
        
        echo $view;
        
    }
    
	/**
	 * Obtiene el controlador de la seccion
	 * @param string $id
	 * @return Controller
	 * @static
	 */
	
	public static function getControllerFrom( $id )
	{
		$section = SectionTree::$sections[ $id ];
		
		if( !($section instanceof Section) )
		{
			trigger_error( 'Se intento obtener el controlador de la seccion inexistente '.$id, E_USER_WARNING );
			
			$controller = Registry::get( 'DEFAULT_CONTROLLER' ).'Controller';
			return new $controller( 'unexistent' );
		}
		
		$controller = $section->get( 'controller' ).'Controller';
		
		if( !class_exists($controller) || !is_subclass_of( $controller, 'Controller' ) )
		{
			if( file_exists( CONTROLLERS.'/class.'.strtolower($controller).'.php' ) )
			{
				include_once CONTROLLERS.'/class.'.strtolower($controller).'.php';
			}
			
			if( !class_exists($controller) || !is_subclass_of( $controller, 'Controller' ) )
			{
				$controller = Registry::get( 'DEFAULT_CONTROLLER' ).'Controller';
			}
		}
		
		return new $controller( $section->get('task'), $id, $id );
	}
}
 
// Fin de archivo
