<?php

/**
 * Definición de la clase Page
 * @package Core
 * @version 3.0
 * @license http://opensource.org/licenses/lgpl-3.0.html GNU Lesser General Public License
 * @copyright TuApp.net 2011
 */

/**
 * Controla la publicación de una página web
 * 
 * @author Andrés Javier López <ajavier.lopez@gmail.com>
 * @copyright TuApp.net 2011
 * @package Core
 * @version 3.0
 */
 
class Page
{
	/**
	 * Nombre de la página
	 * @var string
	 */
	private $page;
	
	/**
	 * Plantillas añadidas a la página
	 * @var array
	 */
	private $templates;
	
	/**
	 * Contenido principal de la página
	 * @var string
	 */
	private $content;
	
	/**
	 * Variables de contenido
	 * @var array
	 */
	private $vars = array();

	/**
	 * Constructor de la clase
	 * @param string $page
	 * @return void
	 */
	public function __construct( $page )
	{
		$this->page = $page;
	}
	
	/**
	 * Método mágico para convertir la clase en una cadena
	 * @return string
	 */
	public function __toString()
	{
		return $this->show();
	}

	/**
	 * Agrega una plantilla a la página
	 * @param string $name
	 * @param string $template
	 * @return void
	 */
	public function addTemplate( $name, $template )
	{
		$this->templates[$name] = $template;
	}
	
	/**
	 * Modifica el contenido principal de la página
	 * @param string $content
	 * @return void
	 */
	public function setContent( $content )
	{
		$this->content = $content;
	}
	
	/**
	 * Modifica las variables de contenido
	 * @param array $vars
	 * @return void
	 */
	public function setVars( $vars )
	{
		$this->vars = $vars;
	}

	/**
	 * Muestra el contenido de la página
	 * @return string
	 */
	public function show()
	{
		$content = $this->process();
		
		return $content;
	}

	/**
	 * Procesa una página para agregar los fragmentos indicados
	 * @return string
	 */
	private function process()
	{
 		$template = new Template( $this->page, true );
		$template->setVars( $this->vars );
		
		$htmlText = $template->show();
		
		preg_match_all('/<md:(\w*|\w+:\w+)\/>/i', $htmlText, $templates);
				
		$htmlText = str_replace('<md:content/>', $this->content, $htmlText);
		foreach($templates[1] as $tpl)
		{
			$texts[$tpl] = $this->loadTemplate($tpl);	
			$htmlText = str_replace('<md:'.$tpl.'/>', $this->loadTemplate($tpl), $htmlText);
		}

		return $htmlText;
	}
	
	/**
	 * Carga la plantilla seleccionada
	 * @param string $template
	 * @return string
	 */
	private function loadTemplate( $template )
	{
		if( isset( $this->templates[$template] ) )
		{
			return $this->templates[$template];
		}
		else
		{
			return Template::load( $template, $this->vars );
		}
	}
}
 
// Fin de archivo
