<?php

/**
 * Definición de la clase SectionTree
 * @package Core
 * @version 3.0
 * @license http://opensource.org/licenses/lgpl-3.0.html GNU Lesser General Public License
 * @copyright TuApp.net 2011
 */

/**
 * Almacena las secciones del sistema
 * 
 * @author Andrés Javier López <ajavier.lopez@gmail.com>
 * @copyright TuApp.net 2011
 * @package Core
 * @version 3.0
 */
 
class SectionTree
{
	/**
	 * Secciones del sistema
	 * @var array
	 * @static
	 */
	public static $sections;

	/**
	 * Agrega una seccion al sistema
	 * @param string $id
	 * @param string $name
	 * @param string[optional] $controller
	 * @param string[optional] $task
	 * @return void
	 * @static
	 */
	public static function addSection( $id, $name, $controller = '', $task = '' )
	{
		if( $controller == '' )
		{
			$controller = Registry::get( 'DEFAULT_CONTROLLER' );
		}
		
		self::$sections[ $id ] = new Section( $id, $name, $controller, $task );
	}
	
	/**
	 * Inicializa las variables de la seccion activa
	 * @param string $id
	 * @return void
	 * @static
	 */
	public static function initSection( $id )
	{
		if(  isset(self::$sections[$id]) && self::$sections[$id] instanceof Section )
		{
			$section = self::$sections[ $id ];
			Registry::set( 'section', $id );
			Registry::set( 'unexistent', false );
		}
		else
		{
			trigger_error( 'Seccion '.$id.' no existe', E_USER_WARNING );// @todo localizar mensaje de error
			$section = self::$sections[Registry::get( 'ERROR_SECTION' )];
			Registry::set( 'section', Registry::get( 'ERROR_SECTION' ) );
			Registry::set( 'unexistent', true );
		}
		
		Registry::set( 'section_name', $section->get('name') );
	}
	
	/**
	 * Carga las secciones a partir de un archivo XML
	 * @param string $file
	 * @return boolean
	 * @static
	 */
	public static function loadFromXML( $file )
	{
		if( !file_exists( $file ) )
		{
			trigger_error( 'No existe el archivo de configuración de secciones del sistema', E_USER_NOTICE ); // @todo localizar contenido
			return false;
		}
		
		$xml = simplexml_load_file( $file );
		
		foreach( $xml->section as $section )
		{
			$controller = isset($section->controller)?$section->controller:'';
			$task = isset($section->task)?$section->task:'';
			
			self::addSection( (string) $section['id'], (string) $section->name, (string) $controller, (string) $task );
		}
		
		return true;
	}
}
 
//Fin de archivo
