<?php

/**
 * Definición de la clase Session
 * @package Core
 * @version 3.0
 * @license http://opensource.org/licenses/lgpl-3.0.html GNU Lesser General Public License
 * @copyright TuApp.net 2011
 */

/**
 * Clase para el manejo de sesiones
 * 
 * @author Andrés Javier López <ajavier.lopez@gmail.com>
 * @copyright TuApp.net 2011
 * @package Core
 * @version 3.0
 */

class Session
{	
	/**
	 * Identificador de la aplicación actual
	 * @var string
	 * @static
	 */
	private static $app_id;
	
	/**
	 * Inicializa la sesión
	 * @return void
	 * @static
	 */
	public static function init()
	{
		session_start();
        
        if(!file_exists('app_id'))
        {
            if(is_writable('.'))
            {
                $app_id = dechex(rand(268435456, 4294967295));
                file_put_contents('app_id', $app_id);
            }
            else
            {
                trigger_error('No se puede generar el id de sesión para la aplicación', E_USER_WARNING);
            }
        }
        
		self::$app_id = file_get_contents('app_id');		
	}
	
   	/**
   	 * Método para acceder a las variables de sesión
   	 * @param string $var
   	 * @return mixed
   	 * @static
   	 */
	public static function get( $var )
   	{
   		if( isset($_SESSION[$var.'_'.self::$app_id] ))
   		{
   			return $_SESSION[$var.'_'.self::$app_id];
   		}
   		else
   		{
   			return NULL;
   		}   		
   	}
   	
   	/**
   	 * Método para modificar las variables de sesión
   	 * @param string $var
   	 * @param mixed $value
   	 * @return void
   	 * @static
   	 */
   	public static function set( $var , $value )
   	{
		$_SESSION[$var.'_'.self::$app_id] = $value;
   	}   
}

// Fin de archivo
