<?php

/**
 * Definición de la clase Template
 * @package Core
 * @version 3.0
 * @license http://opensource.org/licenses/lgpl-3.0.html GNU Lesser General Public License
 * @copyright TuApp.net 2011
 */

/**
 * Manejador de plantillas
 * 
 * @author Andrés Javier López <ajavier.lopez@gmail.com>
 * @copyright TuApp.net 2011
 * @package Core
 * @version 3.0
 */
 
class Template
{
	/**
	 * Nombre de la librería que contiene la plantilla
	 * @var string
	 */
	private $lib = '';
	
	/**
	 * Nombre de la plantilla actual
	 * @var string
	 */
	private $template;
			
	/**
	 * Variables para ser reemplazadas en la plantilla
	 * @var array
	 */
	private $vars = array();
	
	/**
	 * Contenido de la plantilla
	 * @var string
	 */
	private $content = '';
	
	/**
	 * Constructor de la clase
	 * @param string[optional] $template
	 * @param boolean[optional] $page Determina si la plantilla es una página, por defecto es falso 
	 * @return void
	 */
	public function __construct( $template = '', $page = false )
	{
		$this->setTemplate( $template, $page );
	}
	
	/**
	 * Método mágico para convertir el objeto en una cadena
	 * @return string
	 */
	public function __toString()
	{
		return $this->show();
	}

	/**
	 * Modifica la plantilla seleccionada
	 * @param string $template
	 * @param boolean[optional] $page Determina si la plantilla es una página, por defecto es falsa
	 * @return void
	 */
	public function setTemplate( $template, $page = false )
	{
		if( strpos( $template, ':' ) !== false )
		{
			list( $lib, $template ) = explode( ':', $template );
			$this->lib = $lib;
		}
		$this->template =  ($page == true )?'page.'.$template:$template;
		$this->content = '';
	}
	
	/**
	 * Modifica las variables que serán agregadas a la plantilla
	 * @param array $vars
	 * @return void
	 */
	public function setVars( $vars )
	{
		$this->vars = $vars;
	}

	/**
	 * Devuelve el contenido de la plantilla despues de procesarlo
	 * @return string
	 */
	public function show()
	{
		if( $this->content == '' )
		{
			if( $this->readTemplate() )
			{
				$this->replaceVars();
			}
		}
		
		return $this->content;
	}
	
	/**
	 * Lee el archivo de plantilla
	 * @return boolean
	 */
	private function readTemplate()
	{
		if($this->lib != '')
		{
			$file = LIB.'/'.$this->lib.'/templates/'.$this->template.'.tpl';
		}
		else 
		{
			$file =  TPL.'/'.$this->template.'.tpl';
		}
		
		if( !file_exists( $file ) )
		{
			trigger_error( 'La plantilla '.$file.' no existe', E_USER_WARNING );//@todo localizar contenido
			return false;
		}
		
		$file_data = @fopen($file, 'r');
		if ( !$file_data ) 
		{
			$this->content = '';
			trigger_error( 'No se pudo leer la plantilla' , E_USER_WARNING );//@todo localizar contenido
			return false;
		}
		
		$this->content = fread( $file_data, filesize( $file ) );
		fclose( $file_data );
		
		return true;
	}
	
	/**
	 * Reemplaza las variables en la plantilla
	 * @return void
	 */
	private function replaceVars()
	{			
		foreach($this->vars as $key => $var)
		{
			$this->content = str_replace( '[#:'.$key.']', $var, $this->content );
		}
		$this->content = preg_replace( '/\[\#:(\w*)\]/s', '', $this->content );
	}

	/**
	 * Procesa y devuelve la plantilla específicada
	 * @param string $template
	 * @param array[optional] $vars
	 * @param boolean[optional] $page Determina si la plantilla es una página, por defecto es falso
	 * @return string
	 * @static
	 */	
	public static function load( $template, $vars = array(), $page = false )
	{
		$tpl = new self( $template, $page );
		$vars_array = array_merge(  Vars::getVars(), $vars );
		$tpl->setVars( $vars_array );
		return $tpl->show();
	}
}
 
// Fin de archivo
