<?php

/**
 * Definición de la clase View
 * @package Core
 * @version 3.0
 * @license http://opensource.org/licenses/lgpl-3.0.html GNU Lesser General Public License
 * @copyright TuApp.net 2011
 */

/**
 * Vista base para MoonDragon
 * 
 * @author Andrés Javier López <ajavier.lopez@gmail.com>
 * @copyright TuApp.net 2011
 * @package Core
 * @version 3.0
 * @abstract
 */
 
abstract class View
{
	/**
	 * Variables que serán mostradas en la vista
	 * @var array
	 */
	protected $vars;
	
	/**
	 * Constructor base de la vista
	 * @return void
	 */
	public function __construct()
	{
		$this->vars = array();
		Registry::set( 'view', $this );	
	}
	
	/**
	 * Método mágico que convierte el objeto en una cadena
	 * @return string
	 */
	public function __toString()
	{
		return $this->show();
	}
	
	/**
	 * Agrega una variable a la vista
	 * @param string $name
	 * @param string $value
	 * @return void
	 */
	public function addVar( $name, $value )
	{
		$this->vars[$name] = $value;
	}
	
	/**
	 * Devuelve el arreglo de variables que se usarán en la vista
	 * @return array
	 */	
	public function getVars()
	{
		// Esta mezcla es redundante con la que sucede en Template
		// pero se deja así en caso de que la vista no este basada en plantillas 
		$vars = array_merge( Vars::getVars(), $this->vars );
		return $vars;
	}
	
	/**
	 * Muestra el contenido de la vista
	 * @return string
	 * @abstract
	 */
	abstract public function show();
	
	/**
	 * Publica un mensaje
	 * @param string $string
	 * @return void
	 * @abstract
	 */
	abstract public function message( $string );

}
 
// Fin de archivo
