<?php

/**
 * Definición de la clase Lang
 * @package Multilang
 * @version 0.1
 * @license http://opensource.org/licenses/lgpl-3.0.html GNU Lesser General Public License
 * @copyright TuApp.net 2011
 */

/**
 * Herramientas para manipulación de lenguajes múltiples
 * @author Andrés Javier López <ajavier.lopez@gmail.com>
 * @copyright TuApp.net 2011
 * @package Multilang
 * @version 0.1
 * @license http://opensource.org/licenses/lgpl-3.0.html GNU Lesser General Public License
 */

class Lang
{
	/**
	 * Lenguaje actual del sistema
	 * @var string
	 * @static
	 */
	private static $language = 'es';
	
	/**
	 * Cadenas de texto del sistema
	 * @var array
	 * @static
	 */
	private static $strings = array();
	
	/**
	 * Define el lenguaje que se utilizará en el sistema
	 * @param string $language
	 * @return void
	 * @static
	 */
	public static function setLanguage($language)
	{
		if(file_exists(APP.'/languages/'.$language))
		{
			self::$language = $language;
		}
	}
	
	/**
	 * Carga un archivo de lenguaje
	 * @param string $lang
	 * @return void
	 * @static
	 */
	public static function addLanguage($lang)
	{
		include_once APP.'/languages/'.self::$language.'/lang.'.$lang.'.inc';
		
		foreach($langstr as $key => $value)
		{
			self::$strings[$key] = $value;
		}
	}
	
	/**
	 * Obtiene una cadena de texto con el identificador específico
	 * @param string $langid
	 * @return string
	 * @static
	 */
	public static function get($langid)
	{
		if(isset(self::$strings[$langid]))
		{
			return self::$strings[$langid];
		}
		else
		{
			return '';
		}
	}
	
	/**
	 * Carga las cadenas de lenguaje como variables para las plantillas
	 * @return void
	 * @static
	 * @see Vars
	 */	
	public static function fillVars()
	{
		foreach(self::$strings as $key => $string)
		{
			Vars::set($key, $string);
		}
	}
}

// Fin de archivo
